# CryptoAir デバイス SDK

この SDK は、PKCS#11 インターフェースを使用して CryptoAir ハードウェアセキュリティモジュール（HSM）と連携するためのツール、スクリプト、およびサンプルコードを提供します。内容は以下のとおりです：
- 開発およびテスト用のセットアップスクリプト
- `CAIR_Tool`: CryptoAir トークンを管理する CLI ツール
- SoftHSMv2 との相互運用デモ


## ファイル構成

- install.sh, uninstall.sh: CryptoAir の環境セットアップスクリプト
    - wisecure.rules: root 権限なしでデバイスへアクセスできるようにするための udev ルール

- CAIR_Tool: CryptoAir デバイス管理用 CLI ツール

- set_softhsm.sh: デモ用の SofthsmV2 トークンのインストールおよびセットアップスクリプト

- libikvp11.so: p11 ライブラリ、対象 HSM インターフェース
    - pkcs11: pkcs11 3.0 ヘッダを含むディレクトリ

    依存関係:
    - libse.so: p11 とデバイス間の通信を行うトランザクションライブラリ
    - libcrystal.so: ハードウェアに依存しない内部暗号をサポート

- nttdata_hsm.c : 
    CryptoAir と SoftHSMv2 の相互運用性を確認するためのサンプルコード
- nttdata_digest.c:
    Testing Digest function
- Makefile: サンプルコードをビルドするためのスクリプト


## インストールと実行手順

1. 初回は install.sh を実行してください。 `./install.sh`

2. （任意）まだ SofthsmV2 トークンの設定を行っていない場合：set_softhsm.sh を実行してください。 `./set_softhsm.sh`
    * Softhsm ユーザー PIN は現在サンプルコード内で「12345678」にハードコーディングされています

3. サンプルコードに合わせて、CryptoAir のユーザーピンも「12345678」に変更してください

    - (任意) CAIR トークンをリセットし、クリーンな環境から始めてください
        `./CAIR_Tool reset`

    - CAIR トークンのユーザーピンを変更する 

        トークンのリストを表示し、トークンのシリアル番号（SN）を確認します

        `./CAIR_Tool list token`

        Ex:
        --------------------------------------------------------------------------------------------------

        Item    |     Token ID      |          Token Label               |       Token SN
            0      |  6307847252704482 |     token label not set            |  7928272004877601
        --------------------------------------------------------------------------------------------------

    - トークンのユーザーピンを「12345678」に変更します（デフォルトのピンはトークンの SN です）

        ./CAIR_Tool change token_nu pin <token_id> <origin_pin> <new_pin>

        `./CAIR_Tool change token_nu pin 6307847252704482 7928272004877601 12345678 `


3. `make` (nttdata 実行ファイルが生成されます)
4. execute nttdata `./nttdata`


## お問い合わせ先

技術サポートまたはお問い合わせは以下までご連絡ください：

Email: ted@wisecure-tech.jp
