#!/bin/bash

set -e

# Install SoftHSM2
echo "Installing SoftHSM2..."
sudo apt update
sudo apt install -y softhsm2

# Set up the configuration file
echo "Setting up SoftHSM2 config..."
CONFIG_PATH="/etc/softhsm/softhsm2.conf"
TOKEN_DIR="/var/lib/softhsm/tokens"

if [ ! -f "$CONFIG_PATH" ]; then
  sudo mkdir -p "$(dirname "$CONFIG_PATH")"
  sudo tee "$CONFIG_PATH" > /dev/null <<EOF
# SoftHSM v2 configuration file

directories.tokendir = $TOKEN_DIR
objectstore.backend = file
objectstore.umask = 0077

log.level = ERROR
slots.removable = false
slots.mechanisms = ALL
library.reset_on_fork = false
EOF
fi

# Create token directory with correct permissions
echo "Creating token directory..."
sudo mkdir -p "$TOKEN_DIR"
sudo chown -R "$USER" "$(dirname "$TOKEN_DIR")"
sudo chown -R "$USER" "$(dirname "$CONFIG_PATH")"

# Initialize the token
echo "Initializing token..."
softhsm2-util --init-token --slot 0 --label "My token 1" --so-pin "12345678" --pin "12345678"

# Show the token
echo "Verifying created token..."
softhsm2-util --show-slots